@@ -18,4 +18,17 @@ WEATHER_ALERTS = [
     ALERT_WARNING
 ]
 
-DEFAULT_TIMEOUT = 10
\ No newline at end of file
+DEFAULT_TIMEOUT = 10
+
+SUPPORTED_LANGUAGES = [
+    "en",
+    "da",
+    "nl",
+    "es",
+    "de",
+    "fr",
+    "it",
+    "nb",
+    "sv",
+    "pt",
+]
