@@ -34,6 +34,11 @@ class CurrentData:
         self._snow = data["snow"]
         self._uv = data["uv"]
         self._aqi = data["aqi"]
+        self._dhi = data["dhi"]
+        self._dni = data["dni"]
+        self._ghi = data["ghi"]
+        self._elev_angle = data["elev_angle"]
+        self._h_angle = data["h_angle"]
         self._timezone = data["timezone"]
         self._sunrise = data["sunrise"]
         self._sunset = data["sunset"]
@@ -149,7 +154,7 @@ class CurrentData:
 
     @property
     def snow(self) -> float:
-        """Snowfall."""
+        """Snowfall (default mm/hr)."""
         return self._snow
 
     @property
@@ -162,6 +167,31 @@ class CurrentData:
         """Air Quality Index [US - EPA standard 0 - +500]."""
         return self._aqi
 
+    @property
+    def dhi(self) -> float:
+        """Diffuse horizontal solar irradiance (W/m^2) [Clear Sky]."""
+        return self._dhi
+
+    @property
+    def dni(self) -> float:
+        """Direct normal solar irradiance (W/m^2) [Clear Sky]."""
+        return self._dni
+
+    @property
+    def ghi(self) -> float:
+        """Global horizontal solar irradiance (W/m^2) [Clear Sky]."""
+        return self._ghi
+
+    @property
+    def elev_angle(self) -> int:
+        """Solar elevation angle (degrees)."""
+        return self._elev_angle
+
+    @property
+    def h_angle(self) -> int:
+        """Solar hour angle (degrees)."""
+        return self._h_angle
+
     @property
     def timezone(self) -> str:
         """Local IANA Timezone."""
@@ -418,7 +448,7 @@ class ForecastDailyData:
 
     @property
     def snow(self) -> float:
-        """Accumulated Snowfall."""
+        """Accumulated snowfall (default mm)."""
         return self._snow
 
     @property
